#!/bin/bash
#
# uninstall.sh
#
# Copyright (C) 2011-2015 Cesnet z.s.p.o
#
# Use of this source is governed by a BSD-style license, see LICENSE file.  


VERSION="2.2"

#-------------------------------------------------------------------------------
#				Script functions
#-------------------------------------------------------------------------------
usage()
{
	echo "Usage: ${0##*/} -d <directory> [-hV]"
	echo "-d <directory>            Warden client to uninstall"
	echo "-h                        print this help"
	echo "-V                        print script version number and exit"
	echo
	echo "Example: $ ./${0##*/} -d /opt/warden-client"
	echo
	echo "For more information about uninstallation process, see README file (section Uninstallation)."
	echo
	exit 0
}


version()
{
	echo "${0##*/} - current version is $VERSION"
	exit 0
}


err()
{
        echo "FAILED!"
        echo -n "Error: " && cat "$err"
        rm -f "$err"
        rm -rf "$backup"
        echo
        echo "Uninstallation of $package_version package FAILED!!!"
        exit 1
}


errClean()
{
        echo "FAILED!"
        echo -n "Error: " && cat "$err"
        echo " -> Reverting changes of warden client package ... "
        rm -rf "${basedir}/"* > /dev/null 2>&1
        cp -R "${backup}/"* "$basedir"
        rm -f "$err"
        rm -rf "$backup"
        echo
        echo "Uninstallation of $package_version package FAILED!!!"
        exit 1
}


paramsChck()
{
        if [ -z "$basedir" ]; then
                echo "Parameter -d <directory> is not set!"
                exit 1
        fi
}


#-------------------------------------------------------------------------------
#                               Uninstallation functions
#-------------------------------------------------------------------------------

wardenDirChck()
{
        echo -n "Checking Warden client directory ... "
        if [[ ! -d "$basedir" ]]; then
                echo "FAILED!"
                echo "Warden client package is not installed!"
                exit 1
        elif [[ ! -w "$basedir" ]]; then
                echo "FAILED!"
                echo "You don't have permission to Warden client directory!"
                exit 1
        else
                echo "OK"
        fi
}


getPackageVersion()
{
        echo -n "Checking Warden client version ... "
        old_package_version_file=$(find "$basedir" -name package_version)
        if [ -f "$old_package_version_file" ]; then
                package_version=$(<"$old_package_version_file")
                echo "OK"
        else
                echo "FAILED!"
                echo "Warden client is not installed in this directory!"
                exit 1
        fi
}


createBackup()
{
        echo -n "Creating Warden client backup ... "
        [[ -d "$backup" ]] && rm -rf "$backup"
	mkdir "$backup"
        if cp -R "${basedir}/"* "$backup" 2> "$err"; then
                echo "OK"
        else
                err
        fi
}


uninstallWardenClient()
{
        echo -n "Uninstalling $package_version package ... "
        manifest=$(find "$basedir" -name MANIFEST) || err
        for file in $(<"$manifest")
        do
                rm -f "${basedir}/$file" 2> "$err" || errClean
                directory="${file%/*}"
                rmdir --ignore-fail-on-non-empty "${basedir}/$directory" 2> "$err" || errClean
        done
        rm -f "${basedir}/uninstall.sh"
        rmdir --ignore-fail-on-non-empty "$basedir" 2> /dev/null
        echo "OK"
}


#-------------------------------------------------------------------------------
#				MAIN
#-------------------------------------------------------------------------------

# read input
while getopts "d:Vh" options; do
	case $options in
		d ) basedir=$OPTARG;;
		h ) usage;;
		V ) version;;
		* ) usage;;
	esac
done

# remove last char (slash) from name of directories
[[ "$basedir" == */ ]] && basedir="${basedir%?}"

# params test
paramsChck

# set variables
bin="${basedir}/bin"
etc="${basedir}/etc"
doc="${basedir}/doc"
err="/tmp/warden-err"
backup="/tmp/warden-backup"

echo "Uninstallation of Warden client package ..."
echo
echo "------------------------- Uninstallation process ------------------------"

# check Warden client directory if exists
wardenDirChck

# obtain version of existing Warden client (if exists)
getPackageVersion

# make backup of currently installed warden-client package
createBackup

# uninstall Warden client
uninstallWardenClient || exit 1

echo
echo "------------------------- Summary ---------------------------------------"
echo
echo "Uninstallation of $package_version package was SUCCESSFUL!!!"
echo

# cleanup section
rm -r "$err"
rm -rf "$backup"

exit 0
